.. image:: https://readthedocs.org/projects/streaq/badge/?version=latest
   :target: https://streaq.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/streaq
   :target: https://pypi.org/project/streaq
   :alt: PyPI Package

.. image:: https://static.pepy.tech/badge/streaq
   :target: https://pepy.tech/project/streaq
   :alt: PyPI Downloads

.. image:: https://img.shields.io/github/v/release/tastyware/streaq?label=release%20notes
   :target: https://github.com/tastyware/streaq/releases
   :alt: Release

streaQ documentation
====================

Fast, async, type-safe job queuing with Redis streams

.. toctree::
   :maxdepth: 2
   :caption: Documentation:

   installation
   getting-started
   task
   worker
   cli

.. toctree::
   :maxdepth: 2
   :caption: API Reference:

   streaq

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
